@@ -1,13 +1,17 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Algo26\IdnaConvert\NamePrep;
 
 /**
- * @codeCoverageIgnore character mapss
+ * @codeCoverageIgnore character maps
  */
 class NamePrepData2003 extends NamePrepData2008 implements NamePrepDataInterface
 {
-    public $replaceMaps = [
+    public int $version = 2003;
+
+    public array $replaceMaps = [
             0x41 => [0x61], 0x42 => [0x62], 0x43 => [0x63],
             0x44 => [0x64], 0x45 => [0x65], 0x46 => [0x66], 0x47 => [0x67],
             0x48 => [0x68], 0x49 => [0x69], 0x4A => [0x6A], 0x4B => [0x6B],
@@ -303,8 +307,7 @@ class NamePrepData2003 extends NamePrepData2008 implements NamePrepDataInterface
             0x33BA => [0x70, 0x77], 0x33BB => [0x6E, 0x77],
             0x33BC => [0x3BC, 0x77], 0x33BD => [0x6D, 0x77],
             0x33BE => [0x6B, 0x77], 0x33BF => [0x6D, 0x77],
-            0x33C0 => [0x6B, 0x3C9], 0x33C1 => [0x6D, 0x3C9], /*
-            0x33C2  => array(0x61, 0x2E, 0x6D, 0x2E), */
+            0x33C0 => [0x6B, 0x3C9], 0x33C1 => [0x6D, 0x3C9],
             0x33C3 => [0x62, 0x71], 0x33C6 => [0x63, 0x2215, 0x6B, 0x67],
             0x33C7 => [0x63, 0x6F, 0x2E], 0x33C8 => [0x64, 0x62],
             0x33C9 => [0x67, 0x79], 0x33CB => [0x68, 0x70],
